@@ -31,7 +31,7 @@ BEGIN {
     Win32::API::->Import("psapi","BOOL EnumProcessModules(HANDLE  hProcess, HMODULE *lphModule, DWORD   cb, LPDWORD lpcbNeeded)") or die "EnumProcessModules: $^E";  # uncoverable branch true
 }
 
-our $VERSION = '0.005'; # auto-populated from W::M::NPP
+our $VERSION = '0.006'; # auto-populated from W::M::NPP
 
 our @EXPORT_VARS = (@Win32::Mechanize::NotepadPlusPlus::Notepad::Messages::EXPORT);
 
@@ -1173,7 +1173,7 @@ sub destroyScintilla {
     warnings::warnif('deprecated', '->destroyScintilla() method does nothing, so it does not destroy a Scintilla instance [deprecated]');
     return 1;
     # if Don ever re-implements NPPM_DESTROYSCINTILLAHANDLE to properly destroy the scintilla handle, I should re-implement this.
-    if(0) {
+    if(0) { # uncoverable statement
         my ($self,$hwnd) = @_;
 
         $hwnd = $hwnd->hwnd() if ref($hwnd) and (UNIVERSAL::isa($hwnd, 'Win32::Mechanize::NotepadPlusPlus::Editor') or UNIVERSAL::isa($hwnd, 'Win32::Mechanize::NotepadPlusPlus::__hwnd'));    # this makes sure it's the HWND, not an object
@@ -1417,15 +1417,49 @@ sub setStatusBar {
 }
 
 # make _getStatusBar private, since it doesn't work (yet)
-sub _getStatusBar {
-    # There may be a workaround which could be implemented: for each of the sections, compute the default value...
-    #   or see dev-zoom-tooltips.py : npp_get_statusbar()
+#sub _getStatusBar {
+#    # There may be a workaround which could be implemented: for each of the sections, compute the default value...
+#    #   or see dev-zoom-tooltips.py : npp_get_statusbar()
+#    my $self = shift;
+#    my $section = shift;
+#    $section = $STATUSBAR{$section} if exists $STATUSBAR{$section};   # allow name or value
+#    return undef;
+#    #return $self->{_hwobj}->SendMessage_sendStrAsUcs2le( $NPPMSG{NPPM_SETSTATUSBAR} , $section, $text );
+#    # NPPM_GETSTATUSBAR -- Does Not Exist!
+#}
+
+=item getLineNumberWidthMode
+
+=item setLineNumberWidthMode
+
+    $mode = notepad->getLineNumberWidthMode();
+    notepad->setLineNumberWidthMode($mode);
+
+Get or set the line number width mode, either dynamic width mode or
+constant width mode.
+
+C<$mode> uses one of the L<%LINENUMWIDTH|Win32::Mechanize::NotepadPlusPlus::Notepad::Messages/"%LINENUMWIDTH"> values.
+
+These were added in Notepad++ v7.9.2 to allow the line-numbering to be
+constant-width -- so the line number column will have the same width at
+line 1000000 as it shows at line 1000 -- or adjust to the width of the
+line number -- so the line-number column will be wider when you get to
+line 1000000 then when you were at line 1000.  (Prior to v7.9.2, the
+line number width was always dynamic.)
+
+=cut
+
+sub getLineNumberWidthMode {
     my $self = shift;
-    my $section = shift;
-    $section = $STATUSBAR{$section} if exists $STATUSBAR{$section};   # allow name or value
-    return undef;
-    #return $self->{_hwobj}->SendMessage_sendStrAsUcs2le( $NPPMSG{NPPM_SETSTATUSBAR} , $section, $text );
-    # NPPM_GETSTATUSBAR -- Does Not Exist!
+    return $self->SendMessage( $NPPMSG{NPPM_GETLINENUMBERWIDTHMODE} , 0, 0);
+    # NPPM_GETLINENUMBERWIDTHMODE
+}
+
+sub setLineNumberWidthMode {
+    my $self = shift;
+    my $value = shift // 0;
+    return $self->SendMessage( $NPPMSG{NPPM_SETLINENUMBERWIDTHMODE} , 0, $value);
+    # NPPM_GETLINENUMBERWIDTHMODE
 }
 
 =item getMainMenuHandle
@@ -1506,10 +1540,10 @@ sub runMenuCommand {
     # https://github.com/bruderstein/PythonScript/blob/1d9230ffcb2c110918c1c9d36176bcce0a6572b6/PythonScript/src/NotepadPlusWrapper.cpp#L865
     #printf STDERR "\n__%04d__:runMenuCommand(%s)\n", __LINE__, join ", ", map { defined $_ ? qq('$_') : '<undef>'} @_;
     my %opts = ();
-    %opts = %{pop(@_)} if (ref($_[-1]) && UNIVERSAL::isa($_[-1],'hash'));
+    %opts = %{pop(@_)} if ref($_[-1]) and UNIVERSAL::isa($_[-1],'HASH');
     $opts{refreshCache} = 0 unless exists $opts{refreshCache};
 
-    #printf STDERR "\n__%04d__:runMenuCommand(%s, {refreshCache => %s)\n", __LINE__, join(", ", map { defined $_ ? qq('$_') : '<undef>'} @_), $opts{refreshCache};
+    #printf STDERR "\n__%04d__:runMenuCommand(%s, {refreshCache => %s})\n", __LINE__, join(", ", map { defined $_ ? qq('$_') : '<undef>'} @_), $opts{refreshCache};
 
     ## printf STDERR "\n__%04d__:\tcacheMenuCommands = (%s\n\t\t)\n", __LINE__, join("\n\t\t\t", '', map { "'$_' => '$cacheMenuCommands{$_}'" } keys %cacheMenuCommands);
 
@@ -1576,10 +1610,12 @@ sub runPluginCommand {
     }
     sub _findActionInMenu {
         #printf STDERR "\n__%04d__:_findActionInMenu(%s)\n", __LINE__, join ", ", map { defined $_ ? qq('$_') : '<undef>'} @_;
+        #print STDERR "\tcallers = (", join(',', caller), ")\n";
         my $menuID = shift;
         my ($top, @hier) = @_;
         my $count = GetMenuItemCount( $menuID );
         $topID = $menuID unless defined $topID;
+        #printf STDERR "\ttop='%s'(%s)\tcount=%s\thier=(%s)\n", map { $_//'<undef>'} $top, $topID, $count, join('|',@hier);
 
         if($top =~ /\|/) {   # need to split into multiple levels
             # print STDERR "found PIPE '|'\n";
@@ -1587,24 +1623,25 @@ sub runPluginCommand {
             s/^\s+|\s+$//g for @tmp;     # trim spaces
             $top = shift @tmp;          # top is really just the first element of the original top
             unshift @hier, @tmp;        # prepend the @hier with the remaining elements of the split top
-            # print STDERR "new (", join(', ', map { qq/'$_'/ } $top, @hier), ")\n";
+            #print STDERR "new (", join(', ', map { qq/'$_'/ } $top, @hier), ")\n";
         }
 
         for my $idx ( 0 .. $count-1 ) {
             my %h = GetMenuItemInfo( $menuID, $idx );
+            #print STDERR "\t\%h = (", join(', ', grep { $_ } map { "$_ => '$h{$_}'" if exists $h{$_} } qw/type text/),")\n";
             if( $h{type} eq 'string' ) {
                 my $realText = $h{text};
-                (my $cleanText = $realText) =~ s/(\&|\t.*)//;
+                (my $cleanText = $realText) =~ s/(\&|\t.*$)//g; # might have & _and_ \t, so need to use /g
                 if( $top eq $realText or $top eq $cleanText ) {
-                    #print STDERR "FOUND($top): $realText => $cleanText\n";
+                    #print STDERR "# ", __LINE__, " FOUND($top): $realText => $cleanText\n";
                     if( my $submenu = GetSubMenu($menuID, $idx) ) {
                         return _findActionInMenu( $submenu, @hier );
                     } elsif ( my $action = GetMenuItemID( $menuID, $idx ) ) {
-                        #print STDERR "\tthe action ID = $action\n";
+                        #print STDERR "# ", __LINE__, "\tthe action ID = $action\n";
                         return $action;
                     } else {
-                        #print STDERR "\tcouldn't go deeper in the menu\n";
-                        return 0;
+                        #print STDERR "# ", __LINE__, "\tcouldn't go deeper in the menu\n";
+                        return undef;
                     }
                 }
             }
@@ -1613,7 +1650,7 @@ sub runPluginCommand {
                 push @recurse, $submenu;
             }
         }
-        #print STDERR "$menuID# ($top | @hier) wasn't found; try to recurse: (@recurse)\n";
+        #print STDERR "# ", __LINE__, "$menuID# ($top | @hier) wasn't found; try to recurse: (@recurse)\n";
         if($menuID == $topID) { # only try recursion if we're at the top level
             while( my $submenu = shift @recurse ) {
                 my $found = _findActionInMenu( $submenu, $top, @hier );
@@ -1918,6 +1955,22 @@ sub getNppVar {
     return $ret;
 }
 
+=item getSettingsOnCloudPath
+
+    $settings_folder = notepad->getSettingsOnCloudPath();
+
+Get the "Settings on Cloud" path (from B<Settings E<gt> Preferences E<gt> Cloud>). It is useful if plugins want to store its settings on Cloud, if this path is set.
+
+=cut
+
+sub getSettingsOnCloudPath {
+    # NPPM_GETSETTINGSONCLOUDPATH
+    my $self = shift;
+    my $dir = $self->{_hwobj}->SendMessage_getUcs2le($NPPMSG{NPPM_GETSETTINGSONCLOUDPATH},0,{ trim => 'retval+1', wlength => 1 });
+    $dir =~ s/\0*$//;
+    return $dir;
+}
+
 =back
 
 =for comment /end of Meta Information
@@ -2029,6 +2082,9 @@ in L<Win32::Mechanize::NotepadPlusPlus::Editor::Messages>:
 
     use Win32::Mechanize::NotepadPlusPlus ':vars';
 
+The full documentation for the available variables is in L<Win32::Mechanize::NotepadPlusPlus::Notepad::Messages>.
+Additionally, some of frequently-used hashes are summarized below.
+
 =over
 
 =item %NPPMSG
@@ -2042,15 +2098,15 @@ You can find out the names and values of all the messages using:
 
 =item %NPPIDM
 
-This hash contains maps all known message names from L<menuCmdID.h|https://github.com/notepad-plus-plus/notepad-plus-plus/blob/master/PowerEditor/src/menuCmdID.h>, which are useful for passing to the C<SendMessage> method with the NPPM_MENUCOMMAND message.
-
-All of these should be accessible through the L</notepad()-E<gt>runMenuCommand()> method as well.
+This hash contains maps all known message names from L<menuCmdID.h|https://github.com/notepad-plus-plus/notepad-plus-plus/blob/master/PowerEditor/src/menuCmdID.h>, which are useful for passing to the L</notepad()-E<gt>menuCommand()> method (or the C<SendMessage> method with the NPPM_MENUCOMMAND message.)
 
 You can find out the names and values of all the messages using:
 
     use Win32::Mechanize::NotepadPlusPlus ':vars';
     printf "%-40s => %s\n", $_, $NPPIDM{$_} for sort keys %NPPIDM;
 
+... or by looking at the source code for L<Win32::Mechanize::NotepadPlusPlus::Notepad::Messages>.
+
 =item %BUFFERENCODING
 
 The numerical values from this hash can be passed to
@@ -2085,7 +2141,7 @@ or thru the repository's interface at L<https://github.com/pryrt/Win32-Mechanize
 
 =head1 COPYRIGHT
 
-Copyright (C) 2019,2020 Peter C. Jones
+Copyright (C) 2019,2020,2021 Peter C. Jones
 
 =head1 LICENSE
 
