@@ -1,4 +1,4 @@
-# auto-converted from src/menuCmdID.h at Sat Apr  4 13:09:33 2020
+# auto-converted from src/menuCmdID.h at Thu Dec 31 15:14:01 2020
 package Win32::Mechanize::NotepadPlusPlus::__npp_idm;
 
 use warnings;
@@ -32,6 +32,7 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_COLUMNMODETIP'                                     => ((40000 + 2000) + 37),
     'IDM_EDIT_COPY'                                              => ((40000 + 2000) + 2),
     'IDM_EDIT_COPY_BINARY'                                       => ((40000 + 2000) + 48),
+    'IDM_EDIT_COPY_LINK'                                         => ((40000 + 2000) + 82),
     'IDM_EDIT_CURRENTDIRTOCLIP'                                  => ((40000 + 2000) + 31),
     'IDM_EDIT_CUT'                                               => ((40000 + 2000) + 1),
     'IDM_EDIT_CUT_BINARY'                                        => ((40000 + 2000) + 49),
@@ -60,7 +61,8 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_REDO'                                              => ((40000 + 2000) + 4),
     'IDM_EDIT_REMOVEEMPTYLINES'                                  => ((40000 + 2000) + 55),
     'IDM_EDIT_REMOVEEMPTYLINESWITHBLANK'                         => ((40000 + 2000) + 56),
-    'IDM_EDIT_REMOVE_DUP_LINES'                                  => ((40000 + 2000) + 77),
+    'IDM_EDIT_REMOVE_ANY_DUP_LINES'                              => ((40000 + 2000) + 79),
+    'IDM_EDIT_REMOVE_CONSECUTIVE_DUP_LINES'                      => ((40000 + 2000) + 77),
     'IDM_EDIT_RMV_TAB'                                           => ((40000 + 2000) + 9),
     'IDM_EDIT_RTL'                                               => ((40000 + 2000) + 26),
     'IDM_EDIT_SEARCHONINTERNET'                                  => ((40000 + 2000) + 75),
@@ -76,6 +78,9 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_SORTLINES_INTEGER_DESCENDING'                      => ((40000 + 2000) + 62),
     'IDM_EDIT_SORTLINES_LEXICOGRAPHIC_ASCENDING'                 => ((40000 + 2000) + 59),
     'IDM_EDIT_SORTLINES_LEXICOGRAPHIC_DESCENDING'                => ((40000 + 2000) + 60),
+    'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_ASCENDING'            => ((40000 + 2000) + 80),
+    'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_DESCENDING'           => ((40000 + 2000) + 81),
+    'IDM_EDIT_SORTLINES_RANDOMLY'                                => ((40000 + 2000) + 78),
     'IDM_EDIT_SPLIT_LINES'                                       => ((40000 + 2000) + 12),
     'IDM_EDIT_STREAM_COMMENT'                                    => ((40000 + 2000) + 23),
     'IDM_EDIT_STREAM_UNCOMMENT'                                  => ((40000 + 2000) + 47),
@@ -93,7 +98,7 @@ our %nppidm_dummyhash = (
     'IDM_EXPORT_FUNC_LIST_AND_QUIT'                              => ((40000 + 4000) + 73),
     'IDM_FILE'                                                   => (40000 + 1000),
     'IDM_FILEMENU_EXISTCMDPOSITION'                              => 22,
-    'IDM_FILEMENU_LASTONE'                                       => ((40000 + 1000) + 24),
+    'IDM_FILEMENU_LASTONE'                                       => ((40000 + 1000) + 25),
     'IDM_FILESWITCHER_FILESCLOSE'                                => ((40000 + 3500) + 1),
     'IDM_FILESWITCHER_FILESCLOSEOTHERS'                          => ((40000 + 3500) + 2),
     'IDM_FILE_CLOSE'                                             => ((40000 + 1000) + 3),
@@ -102,6 +107,7 @@ our %nppidm_dummyhash = (
     'IDM_FILE_CLOSEALL_TOLEFT'                                   => ((40000 + 1000) + 9),
     'IDM_FILE_CLOSEALL_TORIGHT'                                  => ((40000 + 1000) + 18),
     'IDM_FILE_CLOSEALL_UNCHANGED'                                => ((40000 + 1000) + 24),
+    'IDM_FILE_CONTAININGFOLDERASWORKSPACE'                       => ((40000 + 1000) + 25),
     'IDM_FILE_DELETE'                                            => ((40000 + 1000) + 16),
     'IDM_FILE_EXIT'                                              => ((40000 + 1000) + 11),
     'IDM_FILE_LOADSESSION'                                       => ((40000 + 1000) + 12),
@@ -185,7 +191,6 @@ our %nppidm_dummyhash = (
     'IDM_FORMAT_WIN_1257'                                        => (((40000 + 5000) + 20) + 7),
     'IDM_FORMAT_WIN_1258'                                        => (((40000 + 5000) + 20) + 8),
     'IDM_FORUM'                                                  => ((40000  + 7000)  + 4),
-    'IDM_HELP'                                                   => ((40000  + 7000)  + 8),
     'IDM_HOMESWEETHOME'                                          => ((40000  + 7000)  + 1),
     'IDM_LANG'                                                   => (40000 + 6000),
     'IDM_LANGSTYLE_CONFIG_DLG'                                   => ((40000 + 6000) + 1),
@@ -288,6 +293,7 @@ our %nppidm_dummyhash = (
     'IDM_OPEN_ALL_RECENT_FILE'                                   => ((40000 + 2000) + 40),
     'IDM_PROJECTPAGE'                                            => ((40000  + 7000)  + 2),
     'IDM_SEARCH'                                                 => (40000 + 3000),
+    'IDM_SEARCH_ALLSTYLESTOCLIP'                                 => ((40000 + 3000) + 60),
     'IDM_SEARCH_CLEARALLMARKS'                                   => ((40000 + 3000) + 32),
     'IDM_SEARCH_CLEAR_BOOKMARKS'                                 => ((40000 + 3000) + 8),
     'IDM_SEARCH_COPYMARKEDLINES'                                 => ((40000 + 3000) + 19),
@@ -323,6 +329,7 @@ our %nppidm_dummyhash = (
     'IDM_SEARCH_MARKALLEXT3'                                     => ((40000 + 3000) + 26),
     'IDM_SEARCH_MARKALLEXT4'                                     => ((40000 + 3000) + 28),
     'IDM_SEARCH_MARKALLEXT5'                                     => ((40000 + 3000) + 30),
+    'IDM_SEARCH_MARKEDTOCLIP'                                    => ((40000 + 3000) + 61),
     'IDM_SEARCH_NEXT_BOOKMARK'                                   => ((40000 + 3000) + 6),
     'IDM_SEARCH_PASTEMARKEDLINES'                                => ((40000 + 3000) + 20),
     'IDM_SEARCH_PREV_BOOKMARK'                                   => ((40000 + 3000) + 7),
@@ -330,6 +337,11 @@ our %nppidm_dummyhash = (
     'IDM_SEARCH_SELECTMATCHINGBRACES'                            => ((40000 + 3000) + 53),
     'IDM_SEARCH_SETANDFINDNEXT'                                  => ((40000 + 3000) + 48),
     'IDM_SEARCH_SETANDFINDPREV'                                  => ((40000 + 3000) + 49),
+    'IDM_SEARCH_STYLE1TOCLIP'                                    => ((40000 + 3000) + 55),
+    'IDM_SEARCH_STYLE2TOCLIP'                                    => ((40000 + 3000) + 56),
+    'IDM_SEARCH_STYLE3TOCLIP'                                    => ((40000 + 3000) + 57),
+    'IDM_SEARCH_STYLE4TOCLIP'                                    => ((40000 + 3000) + 58),
+    'IDM_SEARCH_STYLE5TOCLIP'                                    => ((40000 + 3000) + 59),
     'IDM_SEARCH_TOGGLE_BOOKMARK'                                 => ((40000 + 3000) + 5),
     'IDM_SEARCH_UNMARKALLEXT1'                                   => ((40000 + 3000) + 23),
     'IDM_SEARCH_UNMARKALLEXT2'                                   => ((40000 + 3000) + 25),
@@ -377,9 +389,6 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_DRAWTABBAR_MULTILINE'                              => ((40000 + 4000) + 44),
     'IDM_VIEW_DRAWTABBAR_TOPBAR'                                 => ((40000 + 4000) + 7),
     'IDM_VIEW_DRAWTABBAR_VERTICAL'                               => ((40000 + 4000) + 43),
-    'IDM_VIEW_EDGEBACKGROUND'                                    => ((40000 + 4000) + 28),
-    'IDM_VIEW_EDGELINE'                                          => ((40000 + 4000) + 27),
-    'IDM_VIEW_EDGENONE'                                          => ((40000 + 4000) + 37),
     'IDM_VIEW_EOL'                                               => ((40000 + 4000) + 26),
     'IDM_VIEW_FILEBROWSER'                                       => ((40000 + 4000) + 85),
     'IDM_VIEW_FILESWITCHER_PANEL'                                => ((40000 + 4000) + 70),
@@ -422,7 +431,12 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_REDUCETABBAR'                                      => ((40000 + 4000) + 5),
     'IDM_VIEW_REFRESHTABAR'                                      => ((40000 + 4000) + 40),
     'IDM_VIEW_SUMMARY'                                           => ((40000 + 4000) + 49),
+    'IDM_VIEW_SWITCHTO_FILEBROWSER'                              => ((40000 + 4000) + 107),
+    'IDM_VIEW_SWITCHTO_FUNC_LIST'                                => ((40000 + 4000) + 108),
     'IDM_VIEW_SWITCHTO_OTHER_VIEW'                               => ((40000 + 4000) + 72),
+    'IDM_VIEW_SWITCHTO_PROJECT_PANEL_1'                          => ((40000 + 4000) + 104),
+    'IDM_VIEW_SWITCHTO_PROJECT_PANEL_2'                          => ((40000 + 4000) + 105),
+    'IDM_VIEW_SWITCHTO_PROJECT_PANEL_3'                          => ((40000 + 4000) + 106),
     'IDM_VIEW_SYMBOLMARGIN'                                      => ((40000 + 4000) + 13),
     'IDM_VIEW_SYNSCROLLH'                                        => ((40000 + 4000) + 36),
     'IDM_VIEW_SYNSCROLLV'                                        => ((40000 + 4000) + 35),
